summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authoréclairevoyant <848000+eclairevoyant@users.noreply.github.com>2024-06-26 23:11:19 -0400
committeréclairevoyant <848000+eclairevoyant@users.noreply.github.com>2024-06-26 23:14:45 -0400
commit77f61927863bf01e6262fdb724b0aa1654f38b3f (patch)
tree3bc47399c59dad5dff6041ad1bd8c9e6620d98d1
parentaeee4fc133c2e2f4d0d88bb3c6ff9f1947f4d697 (diff)
lib: deprecate mkPackageOptionMD
-rw-r--r--lib/options.nix6
-rw-r--r--nixos/doc/manual/release-notes/rl-2411.section.md2
2 files changed, 5 insertions, 3 deletions
diff --git a/nixos/doc/manual/release-notes/rl-2411.section.md b/nixos/doc/manual/release-notes/rl-2411.section.md
index 984862d5af9e..8fb34ad838d2 100644
--- a/nixos/doc/manual/release-notes/rl-2411.section.md
+++ b/nixos/doc/manual/release-notes/rl-2411.section.md
@@ -144,6 +144,8 @@
not the `hare` package, should be added to `nativeBuildInputs` when building
Hare programs.
+- [`lib.options.mkPackageOptionMD`](https://nixos.org/manual/nixpkgs/unstable#function-library-lib.options.mkPackageOptionMD) is now obsolete; use the identical [`lib.options.mkPackageOption`](https://nixos.org/manual/nixpkgs/unstable#function-library-lib.options.mkPackageOption) instead.
+
- To facilitate dependency injection, the `imgui` package now builds a static archive using vcpkg' CMake rules.
The derivation now installs "impl" headers selectively instead of by a wildcard.
Use `imgui.src` if you just want to access the unpacked sources.
diff --git a/lib/options.nix b/lib/options.nix
index 7e64e6e510fb..f4d0d9d36cfc 100644
--- a/lib/options.nix
+++ b/lib/options.nix
@@ -220,10 +220,10 @@ rec {
(if isList example then "${pkgsText}." + concatStringsSep "." example else example);
});
- /* Alias of mkPackageOption. Previously used to create options with markdown
- documentation, which is no longer required.
+ /* Deprecated alias of mkPackageOption, to be removed in 25.05.
+ Previously used to create options with markdown documentation, which is no longer required.
*/
- mkPackageOptionMD = mkPackageOption;
+ mkPackageOptionMD = lib.warn "mkPackageOptionMD is deprecated and will be removed in 25.05; please use mkPackageOption." mkPackageOption;
/* This option accepts anything, but it does not produce any result.